Module variant_cmax

Module variant_cmax 

Functions

variant_cmax
Helper for VariantN family to access the static cmax utility. In C++ this is a static member of the variadic Variant template. In Rust, we provide it on the base Variant1 and can alias it if needed.