DenseHashTable

Struct DenseHashTable 

pub struct DenseHashTable<K, I, Iface, H, E> { /* private fields */ }
capacity == data.len(), always a power of two or 0. A slot is empty iff its key compares equal to empty_key.

Implementations

Source

impl<K, I, Iface, H, E> DenseHashTable<K, I, Iface, H, E>
where K: Clone, Iface: ItemInterface<K, I>, H: DenseHasher<K> + Default, E: DenseEq<K> + Default,

pub fn dense_hash_table_key_usize(empty_key: K, buckets: usize) -> Self

Source

impl<K, I, Iface, H, E> DenseHashTable<K, I, Iface, H, E>
where K: Clone, Iface: ItemInterface<K, I>, H: DenseHasher<K> + Default, E: DenseEq<K> + Default,

pub fn new(empty_key: K, buckets: usize) -> Self

DenseHashTable(const Key& empty_key, size_t buckets). buckets must be a power of two or 0. Reference: DenseHash.h ctor.