Variant1

Enum Variant1 

pub enum Variant1<T0> {
    V0(T0),
}

Variants



V0(T0)

Implementations

Source

impl<T0> Variant1<T0>

pub const fn cmax(l: &[usize]) -> usize

Source

impl<T0> Variant1<T0>

pub unsafe fn variant_fn_copy<T>(dst: *mut c_void, src: *const c_void)
where T: Clone,

Port of Variant::fnCopy<T>. In the C++ implementation, this is used as a type-erased function pointer to perform a placement-new copy of a specific type T from src to dst.

Safety

This function is unsafe because it performs raw pointer dereferencing and writes to uninitialized memory.

  • dst must be valid for writes and properly aligned for T.
  • src must be valid for reads, properly aligned for T, and contain a valid instance of T.
Source

impl<T0: 'static> Variant1<T0>

Returns Some(&T) if the active alternative has type T, else None.

pub fn get_if<T: 'static>(&self) -> Option<&T>

Source

impl<T0: 'static> Variant1<T0>

pub fn get_type_id<T: 'static>() -> i32

Source

impl<T0> Variant1<T0>

pub fn operator_assign_mut(&mut self, other: Self)

Source

impl<T0: PartialEq> Variant1<T0>

pub fn variant_operator_eq(&self, other: &Self) -> bool

Source

impl<T0> Variant1<T0>
where T0: PartialEq,

pub fn variant_operator_ne(&self, other: &Self) -> bool

Source

impl<T0> Variant1<T0>

pub fn variant(&mut self)

Source

impl<T0: 'static> Variant1<T0>

pub fn variant_t_enable_if_t_get_type_id_t<T: 'static>(value: T) -> Self

Source

impl<T0: Clone> Variant1<T0>

pub fn variant_variant(&self) -> Self

Source

impl<T0: Clone> Variant1<T0>

pub fn variant_variant_mut(&mut self) -> Self

Source

impl<T0> Variant1<T0>

pub fn variant_destructor(&mut self)

Source

impl<T0> Variant1<T0>

pub fn index(&self) -> usize

index() / typeId — the active alternative’s position.

pub fn valueless_by_exception(&self) -> bool

Always false (this port has no valueless state). Matches the C++ valueless_by_exception.

pub fn get_if_0(&self) -> Option<&T0>

pub fn get_if_0_mut(&mut self) -> Option<&mut T0>