pub enum Variant2<T0, T1> {
V0(T0),
V1(T1),
}Variants
Implementations
Sourceimpl<T0: 'static, T1: 'static> Variant2<T0, T1>
Returns Some(&T) if the active alternative has type T, else None.
impl<T0: 'static, T1: 'static> Variant2<T0, T1>
Returns Some(&T) if the active alternative has type T, else None.
Sourceimpl<T0, T1> Variant2<T0, T1>
impl<T0, T1> Variant2<T0, T1>
pub fn operator_assign_mut(&mut self, other: Self)
Sourceimpl<T0: PartialEq, T1: PartialEq> Variant2<T0, T1>
impl<T0: PartialEq, T1: PartialEq> Variant2<T0, T1>
pub fn variant_operator_eq(&self, other: &Self) -> bool
Sourceimpl<T0: 'static, T1: 'static> Variant2<T0, T1>
impl<T0: 'static, T1: 'static> Variant2<T0, T1>
pub fn variant_t_enable_if_t_get_type_id_t<T: 'static>(value: T) -> Self
Sourceimpl<T0: Clone, T1: Clone> Variant2<T0, T1>
impl<T0: Clone, T1: Clone> Variant2<T0, T1>
pub fn variant_variant_mut(&mut self) -> Self
Sourceimpl<T0, T1> Variant2<T0, T1>
impl<T0, T1> Variant2<T0, T1>
pub fn variant_destructor(&mut self)
Sourceimpl<T0, T1> Variant2<T0, T1>
impl<T0, T1> Variant2<T0, T1>
Sourcepub fn valueless_by_exception(&self) -> bool
pub fn valueless_by_exception(&self) -> bool
Always false (this port has no valueless state). Matches the C++
valueless_by_exception.
pub fn get_if_0(&self) -> Option<&T0>
pub fn get_if_0_mut(&mut self) -> Option<&mut T0>
pub fn get_if_1(&self) -> Option<&T1>
pub fn get_if_1_mut(&mut self) -> Option<&mut T1>