pub enum Variant3<T0, T1, T2> {
V0(T0),
V1(T1),
V2(T2),
}Variants
Implementations
Sourceimpl<T0: 'static, T1: 'static, T2: 'static> Variant3<T0, T1, T2>
Returns Some(&T) if the active alternative has type T, else None.
impl<T0: 'static, T1: 'static, T2: 'static> Variant3<T0, T1, T2>
Returns Some(&T) if the active alternative has type T, else None.
Sourceimpl<T0: 'static, T1: 'static, T2: 'static> Variant3<T0, T1, T2>
impl<T0: 'static, T1: 'static, T2: 'static> Variant3<T0, T1, T2>
pub fn get_type_id<T: 'static>() -> i32
Sourceimpl<T0, T1, T2> Variant3<T0, T1, T2>
impl<T0, T1, T2> Variant3<T0, T1, T2>
pub fn operator_assign_mut(&mut self, other: Self)
Sourceimpl<T0: PartialEq, T1: PartialEq, T2: PartialEq> Variant3<T0, T1, T2>
impl<T0: PartialEq, T1: PartialEq, T2: PartialEq> Variant3<T0, T1, T2>
pub fn variant_operator_eq(&self, other: &Self) -> bool
Sourceimpl<T0, T1, T2> Variant3<T0, T1, T2>
impl<T0, T1, T2> Variant3<T0, T1, T2>
pub fn variant_operator_ne(&self, other: &Self) -> bool
Sourceimpl<T0: 'static, T1: 'static, T2: 'static> Variant3<T0, T1, T2>
impl<T0: 'static, T1: 'static, T2: 'static> Variant3<T0, T1, T2>
pub fn variant_t_enable_if_t_get_type_id_t<T: 'static>(value: T) -> Self
Sourceimpl<T0: Clone, T1: Clone, T2: Clone> Variant3<T0, T1, T2>
impl<T0: Clone, T1: Clone, T2: Clone> Variant3<T0, T1, T2>
pub fn variant_variant(&self) -> Self
Sourceimpl<T0: Clone, T1: Clone, T2: Clone> Variant3<T0, T1, T2>
impl<T0: Clone, T1: Clone, T2: Clone> Variant3<T0, T1, T2>
pub fn variant_variant_mut(&mut self) -> Self
Sourceimpl<T0, T1, T2> Variant3<T0, T1, T2>
impl<T0, T1, T2> Variant3<T0, T1, T2>
pub fn variant_destructor(&mut self)
Sourceimpl<T0, T1, T2> Variant3<T0, T1, T2>
impl<T0, T1, T2> Variant3<T0, T1, T2>
Sourcepub fn valueless_by_exception(&self) -> bool
pub fn valueless_by_exception(&self) -> bool
Always false (this port has no valueless state). Matches the C++
valueless_by_exception.
pub fn get_if_0(&self) -> Option<&T0>
pub fn get_if_0_mut(&mut self) -> Option<&mut T0>
pub fn get_if_1(&self) -> Option<&T1>
pub fn get_if_1_mut(&mut self) -> Option<&mut T1>
pub fn get_if_2(&self) -> Option<&T2>
pub fn get_if_2_mut(&mut self) -> Option<&mut T2>