pub enum Variant6<T0, T1, T2, T3, T4, T5> {
V0(T0),
V1(T1),
V2(T2),
V3(T3),
V4(T4),
V5(T5),
}Variants
Implementations
Sourceimpl<T0: 'static, T1: 'static, T2: 'static, T3: 'static, T4: 'static, T5: 'static> Variant6<T0, T1, T2, T3, T4, T5>
Returns Some(&T) if the active alternative has type T, else None.
impl<T0: 'static, T1: 'static, T2: 'static, T3: 'static, T4: 'static, T5: 'static> Variant6<T0, T1, T2, T3, T4, T5>
Returns Some(&T) if the active alternative has type T, else None.
Sourceimpl<T0: 'static, T1: 'static, T2: 'static, T3: 'static, T4: 'static, T5: 'static> Variant6<T0, T1, T2, T3, T4, T5>
impl<T0: 'static, T1: 'static, T2: 'static, T3: 'static, T4: 'static, T5: 'static> Variant6<T0, T1, T2, T3, T4, T5>
pub fn get_type_id<T: 'static>() -> i32
Sourceimpl<T0, T1, T2, T3, T4, T5> Variant6<T0, T1, T2, T3, T4, T5>
impl<T0, T1, T2, T3, T4, T5> Variant6<T0, T1, T2, T3, T4, T5>
pub fn operator_assign_mut(&mut self, other: Self)
Sourceimpl<T0: PartialEq, T1: PartialEq, T2: PartialEq, T3: PartialEq, T4: PartialEq, T5: PartialEq> Variant6<T0, T1, T2, T3, T4, T5>
impl<T0: PartialEq, T1: PartialEq, T2: PartialEq, T3: PartialEq, T4: PartialEq, T5: PartialEq> Variant6<T0, T1, T2, T3, T4, T5>
pub fn variant_operator_eq(&self, other: &Self) -> bool
Sourceimpl<T0, T1, T2, T3, T4, T5> Variant6<T0, T1, T2, T3, T4, T5>
impl<T0, T1, T2, T3, T4, T5> Variant6<T0, T1, T2, T3, T4, T5>
pub fn variant_operator_ne(&self, other: &Self) -> bool
Sourceimpl<T0: 'static, T1: 'static, T2: 'static, T3: 'static, T4: 'static, T5: 'static> Variant6<T0, T1, T2, T3, T4, T5>
impl<T0: 'static, T1: 'static, T2: 'static, T3: 'static, T4: 'static, T5: 'static> Variant6<T0, T1, T2, T3, T4, T5>
pub fn variant_t_enable_if_t_get_type_id_t<T: 'static>(value: T) -> Self
Sourceimpl<T0: Clone, T1: Clone, T2: Clone, T3: Clone, T4: Clone, T5: Clone> Variant6<T0, T1, T2, T3, T4, T5>
impl<T0: Clone, T1: Clone, T2: Clone, T3: Clone, T4: Clone, T5: Clone> Variant6<T0, T1, T2, T3, T4, T5>
pub fn variant_variant(&self) -> Self
Sourceimpl<T0: Clone, T1: Clone, T2: Clone, T3: Clone, T4: Clone, T5: Clone> Variant6<T0, T1, T2, T3, T4, T5>
impl<T0: Clone, T1: Clone, T2: Clone, T3: Clone, T4: Clone, T5: Clone> Variant6<T0, T1, T2, T3, T4, T5>
pub fn variant_variant_mut(&mut self) -> Self
Sourceimpl<T0, T1, T2, T3, T4, T5> Variant6<T0, T1, T2, T3, T4, T5>
impl<T0, T1, T2, T3, T4, T5> Variant6<T0, T1, T2, T3, T4, T5>
pub fn variant_destructor(&mut self)
Sourceimpl<T0, T1, T2, T3, T4, T5> Variant6<T0, T1, T2, T3, T4, T5>
impl<T0, T1, T2, T3, T4, T5> Variant6<T0, T1, T2, T3, T4, T5>
Sourcepub fn valueless_by_exception(&self) -> bool
pub fn valueless_by_exception(&self) -> bool
Always false (this port has no valueless state). Matches the C++
valueless_by_exception.
pub fn get_if_0(&self) -> Option<&T0>
pub fn get_if_0_mut(&mut self) -> Option<&mut T0>
pub fn get_if_1(&self) -> Option<&T1>
pub fn get_if_1_mut(&mut self) -> Option<&mut T1>
pub fn get_if_2(&self) -> Option<&T2>
pub fn get_if_2_mut(&mut self) -> Option<&mut T2>
pub fn get_if_3(&self) -> Option<&T3>
pub fn get_if_3_mut(&mut self) -> Option<&mut T3>
pub fn get_if_4(&self) -> Option<&T4>
pub fn get_if_4_mut(&mut self) -> Option<&mut T4>
pub fn get_if_5(&self) -> Option<&T5>
pub fn get_if_5_mut(&mut self) -> Option<&mut T5>