VecDeque

Struct VecDeque 

pub struct VecDeque<T> { /* private fields */ }

Implementations

Source

impl<T> VecDeque<T>

pub fn capacity(&self) -> usize

Source

impl<T> VecDeque<T>

pub fn empty(&self) -> bool

Source

impl<T> VecDeque<T>

pub fn get_allocator(&self)

Source

impl<T> VecDeque<T>

pub fn is_contiguous(&self) -> bool

Source

impl<T> VecDeque<T>

pub fn is_full(&self) -> bool

Source

impl<T> VecDeque<T>

pub fn max_size(&self) -> usize

Source

impl<T> VecDeque<T>

pub fn operator_assign(&mut self, other: &VecDeque<T>) -> &mut Self

Source

impl<T> VecDeque<T>

pub fn operator_assign_mut(&mut self, other: VecDeque<T>) -> &mut Self

Source

impl<T> VecDeque<T>

pub fn operator_index_mut(&mut self, pos: usize) -> &mut T

Source

impl<T> VecDeque<T>

pub fn operator_index(&self, pos: usize) -> &T

Source

impl<T> VecDeque<T>

pub fn size(&self) -> usize

Source

impl<T> VecDeque<T>

pub fn new() -> Self

Source

impl<T> VecDeque<T>

pub fn with_allocator(_alloc: ()) -> Self

Source

impl<T> VecDeque<T>

pub fn vec_deque_vec_deque(&mut self)

C++ destructor logic for VecDeque. In Rust, this is implemented via the Drop trait on the record itself. This method is a stub for the C++ destructor entry point.

Source

impl<T> VecDeque<T>

pub fn from_init_list(items: Vec<T>) -> Self

VecDeque(std::initializer_list<T>) — construct from a list, reserving exactly the element count so the buffer is contiguous with capacity == size (no growth), matching the C++ initializer-list ctor.

pub fn push_back(&mut self, value: T)

pub fn pop_back(&mut self)

pub fn push_front(&mut self, value: T)

pub fn pop_front(&mut self)

pub fn clear(&mut self)

pub fn reserve(&mut self, new_capacity: usize)

pub fn shrink_to_fit(&mut self)

pub fn at(&self, pos: usize) -> &T

pub fn at_mut(&mut self, pos: usize) -> &mut T

pub fn front(&self) -> &T

pub fn front_mut(&mut self) -> &mut T

pub fn back(&self) -> &T

pub fn back_mut(&mut self) -> &mut T