Functions
- variant_
cmax - Helper for
VariantNfamily to access the staticcmaxutility. In C++ this is a static member of the variadicVarianttemplate. In Rust, we provide it on the baseVariant1and can alias it if needed.
VariantN family to access the static cmax utility.
In C++ this is a static member of the variadic Variant template.
In Rust, we provide it on the base Variant1 and can alias it if needed.