pub enum Variant1<T0> {
V0(T0),
}Variants
V0(T0)
Implementations
Sourceimpl<T0> Variant1<T0>
impl<T0> Variant1<T0>
Sourcepub unsafe fn variant_fn_copy<T>(dst: *mut c_void, src: *const c_void)where
T: Clone,
pub unsafe fn variant_fn_copy<T>(dst: *mut c_void, src: *const c_void)where
T: Clone,
Port of Variant::fnCopy<T>.
In the C++ implementation, this is used as a type-erased function pointer to perform
a placement-new copy of a specific type T from src to dst.
Safety
This function is unsafe because it performs raw pointer dereferencing and writes to uninitialized memory.
dstmust be valid for writes and properly aligned forT.srcmust be valid for reads, properly aligned forT, and contain a valid instance ofT.
Sourceimpl<T0: 'static> Variant1<T0>
Returns Some(&T) if the active alternative has type T, else None.
impl<T0: 'static> Variant1<T0>
Returns Some(&T) if the active alternative has type T, else None.
Sourceimpl<T0> Variant1<T0>
impl<T0> Variant1<T0>
pub fn operator_assign_mut(&mut self, other: Self)
Sourceimpl<T0: PartialEq> Variant1<T0>
impl<T0: PartialEq> Variant1<T0>
pub fn variant_operator_eq(&self, other: &Self) -> bool
Sourceimpl<T0> Variant1<T0>where
T0: PartialEq,
impl<T0> Variant1<T0>where
T0: PartialEq,
pub fn variant_operator_ne(&self, other: &Self) -> bool
Sourceimpl<T0: 'static> Variant1<T0>
impl<T0: 'static> Variant1<T0>
pub fn variant_t_enable_if_t_get_type_id_t<T: 'static>(value: T) -> Self
Sourceimpl<T0> Variant1<T0>
impl<T0> Variant1<T0>
pub fn variant_destructor(&mut self)