pub struct VecDeque<T> { /* private fields */ }Implementations
Sourceimpl<T> VecDeque<T>
impl<T> VecDeque<T>
pub fn get_allocator(&self)
Sourceimpl<T> VecDeque<T>
impl<T> VecDeque<T>
pub fn operator_assign_mut(&mut self, other: VecDeque<T>) -> &mut Self
Sourceimpl<T> VecDeque<T>
impl<T> VecDeque<T>
Sourcepub fn vec_deque_vec_deque(&mut self)
pub fn vec_deque_vec_deque(&mut self)
C++ destructor logic for VecDeque.
In Rust, this is implemented via the Drop trait on the record itself.
This method is a stub for the C++ destructor entry point.
Sourceimpl<T> VecDeque<T>
impl<T> VecDeque<T>
Sourcepub fn from_init_list(items: Vec<T>) -> Self
pub fn from_init_list(items: Vec<T>) -> Self
VecDeque(std::initializer_list<T>) — construct from a list, reserving
exactly the element count so the buffer is contiguous with
capacity == size (no growth), matching the C++ initializer-list ctor.
pub fn push_back(&mut self, value: T)
pub fn pop_back(&mut self)
pub fn push_front(&mut self, value: T)
pub fn pop_front(&mut self)
pub fn clear(&mut self)
pub fn reserve(&mut self, new_capacity: usize)
pub fn shrink_to_fit(&mut self)
pub fn at(&self, pos: usize) -> &T
pub fn at_mut(&mut self, pos: usize) -> &mut T
pub fn front(&self) -> &T
pub fn front_mut(&mut self) -> &mut T
pub fn back(&self) -> &T
pub fn back_mut(&mut self) -> &mut T